.. py:module:: bcdi.utils

.. toctree::
   :maxdepth: 2

:mod:`bcdi.utils`: various utilities for DFT registration and subpixel shift, data loading and fitting, validating parameters
=============================================================================================================================

utilities
^^^^^^^^^

Various non-specific utilities for i/o, fitting curves, generic functions for cropping
or padding a dataset...

API Reference
-------------

.. automodule:: bcdi.utils.utilities
   :members:

image_registration 
^^^^^^^^^^^^^^^^^^

Functions related to image registration and the alignment of datasets in direct or
reciprocal space.

API Reference
-------------

.. automodule:: bcdi.utils.image_registration
   :members:

io_helper
^^^^^^^^^

Class and decorators related to the safe opening of files.

API Reference
-------------

.. automodule:: bcdi.utils.io_helper
   :members:

parameters
^^^^^^^^^^

Classes and functions related to the validation of configuration parameters.

API Reference
-------------

.. automodule:: bcdi.utils.parameters
   :members:

parser
^^^^^^

Class and functions related to loading of the config file and command line parameters.

API Reference
-------------

.. automodule:: bcdi.utils.parser
   :members:

validation
^^^^^^^^^^

This module contains all validation functions that are used throughout the code, in
order to test the input parameters of functions.

API Reference
-------------

.. automodule:: bcdi.utils.validation
   :members:
